<?php

namespace SGalinski\SgNews\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (http://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use SGalinski\ProjectBase\Service\HeaderMetaDataService;
use SGalinski\SgNews\Domain\Model\Category;
use SGalinski\SgNews\Domain\Model\News;
use TYPO3\CMS\Core\Utility\GeneralUtility;

/**
 * Controller that handles the list rendering of a single category
 */
class ListByCategoryController extends AbstractController {
	/**
	 * @inject
	 * @var \SGalinski\SgNews\Domain\Repository\CategoryRepository
	 */
	protected $categoryRepository;

	/**
	 * @inject
	 * @var \SGalinski\SgNews\Domain\Repository\NewsRepository
	 */
	protected $newsRepository;

	/**
	 * Renders the news list of a category
	 *
	 * @return void
	 */
	public function indexAction() {
		/** @var Category $selectedCategory */
		$selectedCategoryId = (int) $GLOBALS['TSFE']->id;
		$selectedCategory = $this->categoryRepository->findByUid($selectedCategoryId);
		if (!$selectedCategory) {
			return;
		}
		$offset = 0;
		$newsPerPage = (int) $this->settings['newsLimitPerPage'];
		$currentPageBrowserPage = (int) GeneralUtility::_GP('tx_pagebrowse_pi1')['page'];
		if ($currentPageBrowserPage && $newsPerPage) {
			$offset = $currentPageBrowserPage * $newsPerPage;
		}

		/** @noinspection PhpUndefinedMethodInspection */
		$newsCount = $this->newsRepository->countByPid($selectedCategoryId);
		$numberOfPages = ceil($newsCount / $newsPerPage);
		$news = $this->newsRepository->findAllSortedNewsByCategory($selectedCategoryId, $newsPerPage, $offset);
		$news = $news->toArray();

		$highlightedNews = NULL;
		if ($currentPageBrowserPage <= 1) {
			$highlightedNews = $this->newsRepository->findLastUpdatedOrHighlightedNewsByCategory(
				1, FALSE, $selectedCategoryId
			)->getFirst();

			if ($highlightedNews && !in_array($highlightedNews, $news)) {
				$news[] = $highlightedNews;
			}
		}

		$newsMetaData = $highlightedNewsMetaData = [];
		foreach ($news as $newsEntry) {
			/** @var News $newsEntry */
			$data = $this->getMetaDataForNews($newsEntry, $selectedCategory);
			if ($newsEntry === $highlightedNews) {
				$highlightedNewsMetaData = $data;
				continue;
			}
			$newsMetaData[] = $data;
		}

		if ($highlightedNewsMetaData['image']) {
			HeaderMetaDataService::addOgImageToHeader($highlightedNewsMetaData['image']);
		} elseif ($highlightedNewsMetaData['teaserImage']) {
			HeaderMetaDataService::addOgImageToHeader($highlightedNewsMetaData['teaserImage']);
		}

		$this->view->assign('numberOfPages', $numberOfPages);
		$this->view->assign('newsMetaData', $newsMetaData);
		$this->view->assign('category', $selectedCategory);
		$this->view->assign('highlightedNewsMetaData', $highlightedNewsMetaData);
	}
}

?>
